@@ -118,38 +118,46 @@ class NeptuneExperimentTracker(ExperimentTracker):
         loggable = self.project if projectLevel else self.tracker
 
         for (key, value) in valueMap.items():
-            if f"{path}/{key}" in loggable:
-                del loggable[f"{path}/{key}"]
-
-            if isinstance(value, Figure):
-                fileHandle, previewHandle = BytesIO(), BytesIO()
-                value.savefig(fileHandle, format="svg", bbox_inches="tight")
-                loggable[f"{path}/{key}"].upload(
-                    File.from_stream(fileHandle, extension="svg")
-                )
-                value.savefig(previewHandle, format="png", bbox_inches="tight")
-                loggable[f"{path}/{key} preview"].upload(
-                    File.from_stream(previewHandle, extension="png")
-                )
-            elif isinstance(value, PlotlyFigure):
-                loggable[f"{path}/{key}"].upload(
-                    File.from_content(to_html(value), extension="html")
-                )
-            elif isinstance(value, DataFrame):
-                tableStream = BytesIO()
-                value.to_csv(tableStream, header=True, index=True)
-                loggable[f"{path}/{key}"].upload(
-                    File.from_stream(tableStream, extension="csv")
-                )
-            elif key == "model":
-                loggable[f"{path}/{key}"].upload(
-                    File.from_stream(BytesIO(value), extension="pkl")
-                )
-            elif isinstance(value, BytesIO) or isinstance(value, StringIO):
-                loggable[f"{path}/{key}"].upload(File.from_stream(value))
-            else:
-                loggable[f"{path}/{key}"] = value
+            existingData = None
+            try:
+                if f"{path}/{key}" in loggable:
+                    # reset data type by erasing
+                    existingData = loggable[f"{path}/{key}"]
+                    del loggable[f"{path}/{key}"]
 
+                if isinstance(value, Figure):
+                    fileHandle, previewHandle = BytesIO(), BytesIO()
+                    value.savefig(fileHandle, format="svg", bbox_inches="tight")
+                    loggable[f"{path}/{key}"].upload(
+                        File.from_stream(fileHandle, extension="svg")
+                    )
+                    value.savefig(previewHandle, format="png", bbox_inches="tight")
+                    loggable[f"{path}/{key} preview"].upload(
+                        File.from_stream(previewHandle, extension="png")
+                    )
+                elif isinstance(value, PlotlyFigure):
+                    loggable[f"{path}/{key}"].upload(
+                        File.from_content(to_html(value), extension="html")
+                    )
+                elif isinstance(value, DataFrame):
+                    tableStream = BytesIO()
+                    value.to_csv(tableStream, header=True, index=True)
+                    loggable[f"{path}/{key}"].upload(
+                        File.from_stream(tableStream, extension="csv")
+                    )
+                elif key == "model":
+                    loggable[f"{path}/{key}"].upload(
+                        File.from_stream(BytesIO(value), extension="pkl")
+                    )
+                elif isinstance(value, BytesIO) or isinstance(value, StringIO):
+                    loggable[f"{path}/{key}"].upload(File.from_stream(value))
+                else:
+                    loggable[f"{path}/{key}"] = value
+                except:
+                    if existingData:
+                        # reset existing data upon error
+                        loggable[f"{path}/{key}"] = existingData
+                
     def addTags(self, tags: List):
         self.tracker["sys/tags"].add(tags)
 
